@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.013000';
+$MetaCPAN::Client::VERSION = '2.013001';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -81,7 +81,7 @@ sub package {
     my $arg    = shift;
     my $params = shift;
 
-    return $self->_get_or_search( 'packages', $arg, $params );
+    return $self->_get_or_search( 'package', $arg, $params );
 }
 
 sub permission {
@@ -234,7 +234,6 @@ sub _get {
         or croak sprintf( 'Failed to fetch %s (%s)', ucfirst($type), $arg );
 
     $type = 'DownloadURL' if $type eq 'download_url';
-    $type = 'Package'     if $type eq 'packages';
 
     my $class = 'MetaCPAN::Client::' . ucfirst($type);
     return $class->new_from_request($response, $self);
@@ -391,7 +390,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.013000
+version 2.013001
 
 =head1 SYNOPSIS
 
